@@ -1,50 +1,111 @@
 from typing import Dict
+import random
 
+def random_get(dic: dict, str_key: str, mode:str = "static"):
+    if mode == "static":
+        count = sum([ord(c) for c in str_key])
+        keys = list(dic.keys())
+        return dic[keys[count % len(keys)]]
+    else:
+        keys = list(dic.keys())
+        return dic[random.choice(keys)]
 
-select: Dict[str, str] = {}
-select["shark"] = r"""
- r -> Roda sem testar                                        
-                                    _________         .    . 
- t -> Testa usando casos de teste  (..       \_    ,  |\  /| 
-                                    \       O  \  /|  \ \/ / 
- p -> Muda o arquivo principal       \______    \/ |   \  /  
-      para problemas de múltiplos       vvvv\    \ |   /  |  
-      arquivos de código fonte          \^^^^  ==   \_/   |  
-                                         `\_   ===    \.  |  
- m -> muda o modo diff de vertical       / /\_   \ /      |  
-      para modo diff horizontal          |/   \_  \|      /  
-                                                \________/   
- direcionais -> muda o teste                                 
-"""
+opening: Dict[str, str] = {}
 
-select["cat"] = r"""
- ,_     _          r -> Roda sem testar             
- |\\_,-~/                                           
- / _  _ |    ,--.  t -> Testa usando casos de teste 
-(  @  @ )   / ,-'                                   
- \  _T_/-._( (     p -> Muda o arquivo principal    
- /         `. \         para problemas de múltiplos 
-|         _  \ |        arquivos de código fonte    
- \ \ ,  /      |                                    
-  || |-_\__   /    m -> muda o modo diff de vertical
- ((_/`(____,-'          para modo diff horizontal   
-                                                    
-                   direcionais -> muda o teste      
-"""
+# opening["parrot"] = r"""
+#                            .    
+#                           | \/| 
+#                           ) )|/|
+#                     _----. /.'.'
+# .-._________..      .' @ _\  .' 
+# '.._______.   '.   /    (_| .') 
+#   '._____.  /   '-/      | _.'  
+#    '.______ (         ) ) \     
+#      '..____ '._       )  )     
+#         .' __.--\  , ,  // ((   
+#         '.'     |  \/   (_.'(   
+#                 '   \ .'        
+#                  \   (          
+#                   \   '.        
+#                    \ \ '.)      
+#                     '-'-'       
+# """
 
-select["elephant"] = r"""
-        ⣀⣀               r -> Roda sem testar             
-      ⣰⣿⣿⣿⣿⣦⣀⣀⣀                                           
-      ⢿⣿⠟⠋⠉    ⠉⠑⠢⣄⡀     t -> Testa usando casos de teste 
-     ⢠⠞⠁           ⠙⢿⣿⣿⣦⡀                                 
- ⣀  ⢀⡏ ⢀⣴⣶⣶⡄         ⢻⣿⣿⠇p -> Muda o arquivo principal    
-⣾⣿⣿⣦⣼⡀ ⢺⣿⣿⡿⠃    ⣠⣤⣄  ⠈⡿⠋      para problemas de múltiplos 
-⢿⣿⣿⣿⣿⣇ ⠤⠌⠁ ⡀⢲⡶⠄⢸⣏⣿⣿   ⡇       arquivos de código fonte    
-⠈⢿⣿⣿⣿⣿⣷⣄⡀  ⠈⠉⠓⠂ ⠙⠛⠛⠠ ⡸⠁                                   
-  ⠻⣿⣿⣿⣿⣿⣿⣷⣦⣄⣀    ⠑ ⣠⠞⠁   m -> muda o modo diff de vertical
-   ⢸⡏⠉⠛⠛⠛⠿⠿⣿⣿⣿⣿⣿⣿⣿⣿⡄          para modo diff horizontal   
-   ⠸        ⠈⠉⠛⢿⣿⣿⣿⣿⡄                                     
-   ⢷           ⠈⢻⣿⣿⣿⣿⡀   direcionais -> muda o teste      
+opening["estuda"] = r"""
+------- O modelo de avaliação utiliza 3 critérios --------
+
+- Cobertura: quanto da atividade foi entregue\?
+  - Se houver testes, isso será calculado automaticamente
+- Abordagem: como foi a última execução da atividade\?
+  - Copiar, ChatGpt, Copilot, Aula, Monitoria, Sozinho
+- Autonomia: se refizer a atividade sozinho e SEM CONSULTA, 
+    quanto dela você se sente confiante para fazer\?
+
+Cobertura: (  fiz nada ) 0 1 ... 9 ✓ (entreguei tudo)
+Abordagem: (muita ajuda) x E D C B A (nenhum suporte)
+Autonomia: (não aprendi) x ▁ ▂ ▃ ▅ █ (refaço sozinho)
+
+ ,`````.          __||||___       
+' Estuda`,       /_  ___   \      
+'miserável`.    /@ \/@  \   \     
+ ` , . , '  `.. \__/\___/   /     
+                 \_\/______/      
+                 /     /\\\\\     
+                |     |\\\\\\     
+                 \      \\\\\\    
+                  \______/\\\\    
+            _______ ||_||_______  
+           (______(((_(((______(@)
+"""[1:]
+
+# opening["alien4"] = r"""
+#             ______              ______
+#            /___   \___\ || /___/   ___\
+#           //\]/\ ___  \\||//  ___ /\[/\\
+#           \\/[\//  _)   \/   (_  \\/]\//
+#            \___/ _/   o    o   \_ \___/
+#                _/                \_
+#               //'VvvvvvvvvvvvvvvV'\\
+#              ( \.'^^^^^^^^^^^^^^'./ )
+#               \____   . .. .   ____/
+#    ________        \ . .''. . /        ________
+#   /______  \________)________(________/ _______\
+#  /|       \ \  Estuda seu miserável  / /       |\
+# (\|____   / /                        \ \   ____|/)
+# """
+
+# opening["alien5"] = r"""
+#                    ⢀⡀⠤⠤⠤⠄ ⠒⠢⣄    
+#                 ⡠⠐⢈⠄        ⢸⠓⠄  
+#               ⠐⠈⠠⠊         ⡠⠊ ⠈⢂ 
+#             ⢀⠊ ⡐⠁        ⢠⢊⠔⠈   ⠆
+#            ⣠⡃ ⢰    ⢀⡠⠄⠐⠒ ⢸⢜⠄     
+#           ⡐⣁⡑ ⠘  ⢀⠔⢁⣀⣤⣤⣤⣒⣤ ⠈    ⡄
+#           ⢫⣿⢧ ⢸  ⣡⣶⣯⠭⢄⣀⣼⡏⠁⢀⡤   ⢐⠁
+#           ⢠⢿⣾⣧⠈ ⢠⣿⣿⣗⢢⣤⣿⡿⢋ ⡏    ⡌ 
+#    Gosto  ⠘⠳⠙⠻  ⠰⠿⠟⠛⠻⢍⠫⠒⠁⡰   ⢀⠜  
+#     de    ⠘⢄          ⢀⠠⢊ ⡇⢠⠒⠁   
+#    comer    ⠈⢦⠂    ⢠⠊⠁ ⢀⠄ ⡇⢸     
+#  cérebros    ⠘⢄⡄⢤⢄ ⠘⡄  ⡀⠄⢊⡅⡆⢆    
+#     de         ⢊   ⠈⢁⠴⠅⣀⣀⠘⢣⠠⠈⠢⢀  
+#   alunos       ⠈⠢⢄⣀⡠⠊  ⠈⢣ ⠈⠃⠡  ⠉⠐
+# preguiçosos             ⠰⠇  ⠐⡑⠤⢀ 
+# """
+
+intro: Dict[str, str] = {}
+
+intro["elephant"] = r"""
+        ⣀⣀                                                                      
+      ⣰⣿⣿⣿⣿⣦⣀⣀⣀           ↲ -> avalia usando os testes cadastrados no cases.tio 
+      ⢿⣿⠟⠋⠉    ⠉⠑⠢⣄⡀      r -> compila e (r)oda fazendo entrada de dados manual 
+     ⢠⠞⠁           ⠙⢿⣿⣿⣦⡀                                                       
+ ⣀  ⢀⡏ ⢀⣴⣶⣶⡄         ⢻⣿⣿⠇ TAB -> Muda o arquivo PRINCIPAL se múltiplos arquivos 
+⣾⣿⣿⣦⣼⡀ ⢺⣿⣿⡿⠃    ⣠⣤⣄  ⠈⡿⠋                                                        
+⢿⣿⣿⣿⣿⣇ ⠤⠌⠁ ⡀⢲⡶⠄⢸⣏⣿⣿   ⡇   d -> muda o modo (d)iff de vertical para horizontal   
+⠈⢿⣿⣿⣿⣿⣷⣄⡀  ⠈⠉⠓⠂ ⠙⠛⠛⠠ ⡸⠁   u -> trava a avaliação em (u)m único caso de teste    
+  ⠻⣿⣿⣿⣿⣿⣿⣷⣦⣄⣀    ⠑ ⣠⠞⠁    t -> define o limite de (t)empo para execução         
+   ⢸⡏⠉⠛⠛⠛⠿⠿⣿⣿⣿⣿⣿⣿⣿⣿⡄                                                            
+   ⠸        ⠈⠉⠛⢿⣿⣿⣿⣿⡄     esquerda direita -> muda o teste apresentado          
 """
 
 compilling: Dict[str, str] = {}
@@ -63,14 +124,6 @@ compilling: Dict[str, str] = {}
 # """
 
 
-numbers = r"""
-  __    __     _   ____  ____   ___   ___   ___  ____  ____  ___  
- /  \  /  \   / ) (___ \( __ \ / _ \ / __) / __)(__  )/ _  \/ _ \ 
-(  0 )(_/ /  / /   / __/ (__ ((__  ((___ \(  _ \  / / ) _  (\__  )
- \__/  (__) (_/   (____)(____/  (__/(____/ \___/ (_/  \____/(___/ 
-"""
-
-
 executing: str = r"""
 ███████╗██╗  ██╗███████╗ ██████╗██╗   ██╗████████╗ █████╗ ███╗   ██╗██████╗  ██████╗ 
 ██╔════╝╚██╗██╔╝██╔════╝██╔════╝██║   ██║╚══██╔══╝██╔══██╗████╗  ██║██╔══██╗██╔═══██╗
@@ -89,16 +142,6 @@ compilling["computer"] = r"""
  ╚═════╝ ╚═════╝ ╚═╝     ╚═╝╚═╝     ╚═╝╚══════╝╚═╝  ╚═╝╚═╝  ╚═══╝╚═════╝  ╚═════╝ 
 """
 
-# compilling["edge]"] = r"""
-# ▄█▄    ████▄ █▀▄▀█ █ ▄▄  ▄█ █    ██      ▄   ██▄   ████▄
-# █▀ ▀▄  █   █ █ █ █ █   █ ██ █    █ █      █  █  █  █   █
-# █   ▀  █   █ █ ▄ █ █▀▀▀  ██ █    █▄▄█ ██   █ █   █ █   █
-# █▄  ▄▀ ▀████ █   █ █     ▐█ ███▄ █  █ █ █  █ █  █  ▀████
-# ▀███▀           █   █     ▐     ▀   █ █  █ █ ███▀       
-#                ▀     ▀             █  █   ██            
-#                                   ▀                     
-# """
-
 success: Dict[str, str] = {}
 
 
@@ -111,49 +154,6 @@ success["success"] = r"""
 ╚══════╝ ╚═════╝  ╚═════╝╚══════╝╚══════╝╚══════╝ ╚═════╝ 
 """
 
-# success["success3"] = r"""
-#   ██████  █    ██  ▄████▄  ▓█████   ██████   ██████  ▒█████  
-# ▒██    ▒  ██  ▓██▒▒██▀ ▀█  ▓█   ▀ ▒██    ▒ ▒██    ▒ ▒██▒  ██▒
-# ░ ▓██▄   ▓██  ▒██░▒▓█    ▄ ▒███   ░ ▓██▄   ░ ▓██▄   ▒██░  ██▒
-#   ▒   ██▒▓▓█  ░██░▒▓▓▄ ▄██▒▒▓█  ▄   ▒   ██▒  ▒   ██▒▒██   ██░
-# ▒██████▒▒▒▒█████▓ ▒ ▓███▀ ░░▒████▒▒██████▒▒▒██████▒▒░ ████▓▒░
-# ▒ ▒▓▒ ▒ ░░▒▓▒ ▒ ▒ ░ ░▒ ▒  ░░░ ▒░ ░▒ ▒▓▒ ▒ ░▒ ▒▓▒ ▒ ░░ ▒░▒░▒░ 
-# ░ ░▒  ░ ░░░▒░ ░ ░   ░  ▒    ░ ░  ░░ ░▒  ░ ░░ ░▒  ░ ░  ░ ▒ ▒░ 
-# ░  ░  ░   ░░░ ░ ░ ░           ░   ░  ░  ░  ░  ░  ░  ░ ░ ░ ▒  
-#       ░     ░     ░ ░         ░  ░      ░        ░      ░ ░  
-#                   ░                                          
-# """
-
-# success["success4"] = r"""
-#   █████████                                                       
-#  ███░░░░░███                                                      
-# ░███    ░░░  █████ ████  ██████   ██████   █████   █████   ██████ 
-# ░░█████████ ░░███ ░███  ███░░███ ███░░███ ███░░   ███░░   ███░░███
-#  ░░░░░░░░███ ░███ ░███ ░███ ░░░ ░███████ ░░█████ ░░█████ ░███ ░███
-#  ███    ░███ ░███ ░███ ░███  ███░███░░░   ░░░░███ ░░░░███░███ ░███
-# ░░█████████  ░░████████░░██████ ░░██████  ██████  ██████ ░░██████ 
-#  ░░░░░░░░░    ░░░░░░░░  ░░░░░░   ░░░░░░  ░░░░░░  ░░░░░░   ░░░░░░  
-# """
-
-# success["success5"] = r"""
-# .▄▄ · ▄• ▄▌ ▄▄· ▄▄▄ ..▄▄ · .▄▄ ·       
-# ▐█ ▀. █▪██▌▐█ ▌▪▀▄.▀·▐█ ▀. ▐█ ▀. ▪     
-# ▄▀▀▀█▄█▌▐█▌██ ▄▄▐▀▀▪▄▄▀▀▀█▄▄▀▀▀█▄ ▄█▀▄ 
-# ▐█▄▪▐█▐█▄█▌▐███▌▐█▄▄▌▐█▄▪▐█▐█▄▪▐█▐█▌.▐▌
-#  ▀▀▀▀  ▀▀▀ ·▀▀▀  ▀▀▀  ▀▀▀▀  ▀▀▀▀  ▀█▄▀▪
-# """
-
-# success["success6"] = r"""
-#    ▄▄▄▄▄   ▄   ▄█▄    ▄███▄     ▄▄▄▄▄    ▄▄▄▄▄   ████▄
-#   █     ▀▄  █  █▀ ▀▄  █▀   ▀   █     ▀▄ █     ▀▄ █   █
-# ▄  ▀▀▀▀▄ █   █ █   ▀  ██▄▄   ▄  ▀▀▀▀▄ ▄  ▀▀▀▀▄   █   █
-#  ▀▄▄▄▄▀  █   █ █▄  ▄▀ █▄   ▄▀ ▀▄▄▄▄▀   ▀▄▄▄▄▀    ▀████
-#          █▄ ▄█ ▀███▀  ▀███▀                           
-#           ▀▀▀                                         
-# """
-
-# --------------------------------------------------------------
-
 images: Dict[str, str] = {}
 
 images["pink"] = r"""
@@ -175,15 +175,6 @@ Programando assim, você vai dominar o mundo!
            `.,'   |; \          \`\_,/-'  \'      
             .'    l \ `.        /"\ _ \`  j       
             f      : `-'        `._;."/`-'        
-            |      `.               ,7  \         
-            l       j             .'/ - \`.       
-           .j.  .   <            (.'    .\ \f`. |\
-          ,' `.  \ / \           `|      \,'||-:j 
-        .'  .'\   Y.  \___......__\ ._   /`.||    
-__.._,-" .-"'"")  /' ,' _          \ |  /"-.`j""``
-  .'_.-'"     / .("-'-"":\        ._)|_(__. "'    
- ;.'         /-'---"".--"'       /,_,^-._ .)      
- `:=.__.,itz `---._.;'
 """
 
 images["batman"] = r"""
@@ -305,12 +296,6 @@ vou aumentar a dificuldade!
   `HH `.      ,'   /     |@@@@@ @@@@.  `.           / /(~)
    HH   \_   ,'  _/`.    |@@@@@ @@@@@;  `.          ; (~~)
    ~~`.   \_,'  /   ;   .@@@@@ @@@@@@;\_  \___      ; H~\)
-       \_     _/    `.  |@@@@@@ @@@@@;  \     `----'_HH[~)
-         \___/       `. :@@@@@ @@@@@@'   \__,------' HH ~ 
-        ______        ; |@@@@@@ @@@'                 HH   
-      _)      \_,     ; :@@@@@@@@@;                  ~~   
-    _;          \\   ,' |@@@@@@@@@:                       
-
 """
 
 images["piupiu"] = r"""
@@ -421,7 +406,6 @@ O código ficou lindo dessa vez!
         ⠻⢿⣟⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠏       
           ⠘⠻⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠁        
              ⠙⠿⢿⣿⣿⣿⡿⠋          
-Ou será que não?
 """
 
 images["pikachu"] = r"""
